@@ -1,5 +1,5 @@
 """Top-level package for geospatial."""
 
 __author__ = """Qiusheng Wu"""
-__email__ = 'giswqs@gmail.com'
-__version__ = '0.7.0'
+__email__ = "giswqs@gmail.com"
+__version__ = "0.11.0"
